@@ -16,10 +16,12 @@
 # Import APIs into API package:
 from openapi_client.api.catalogs_api import CatalogsApi
 from openapi_client.api.client_api import ClientApi
+from openapi_client.api.data_privacy_api import DataPrivacyApi
 from openapi_client.api.events_api import EventsApi
 from openapi_client.api.flows_api import FlowsApi
 from openapi_client.api.lists_api import ListsApi
 from openapi_client.api.metrics_api import MetricsApi
 from openapi_client.api.profiles_api import ProfilesApi
 from openapi_client.api.segments_api import SegmentsApi
+from openapi_client.api.tags_api import TagsApi
 from openapi_client.api.templates_api import TemplatesApi
