@@ -16,6 +16,9 @@ from openapi_client.model.campaign_clone_query_as_sub_resource_attributes import
 from openapi_client.model.campaign_create_query import CampaignCreateQuery
 from openapi_client.model.campaign_create_query_as_sub_resource import CampaignCreateQueryAsSubResource
 from openapi_client.model.campaign_create_query_as_sub_resource_attributes import CampaignCreateQueryAsSubResourceAttributes
+from openapi_client.model.campaign_message_assign_template_query import CampaignMessageAssignTemplateQuery
+from openapi_client.model.campaign_message_assign_template_query_as_sub_resource import CampaignMessageAssignTemplateQueryAsSubResource
+from openapi_client.model.campaign_message_assign_template_query_as_sub_resource_attributes import CampaignMessageAssignTemplateQueryAsSubResourceAttributes
 from openapi_client.model.campaign_message_partial_update_query import CampaignMessagePartialUpdateQuery
 from openapi_client.model.campaign_message_partial_update_query_as_sub_resource import CampaignMessagePartialUpdateQueryAsSubResource
 from openapi_client.model.campaign_message_partial_update_query_as_sub_resource_attributes import CampaignMessagePartialUpdateQueryAsSubResourceAttributes
@@ -118,11 +121,9 @@ from openapi_client.model.included_lists import IncludedLists
 from openapi_client.model.included_lists_attributes import IncludedListsAttributes
 from openapi_client.model.included_metrics import IncludedMetrics
 from openapi_client.model.included_metrics_attributes import IncludedMetricsAttributes
-from openapi_client.model.included_profile import IncludedProfile
 from openapi_client.model.included_profiles import IncludedProfiles
 from openapi_client.model.included_profiles_attributes import IncludedProfilesAttributes
 from openapi_client.model.included_segments import IncludedSegments
-from openapi_client.model.included_tags import IncludedTags
 from openapi_client.model.included_variants import IncludedVariants
 from openapi_client.model.included_variants_attributes import IncludedVariantsAttributes
 from openapi_client.model.included_variants_links import IncludedVariantsLinks
@@ -161,7 +162,6 @@ from openapi_client.model.segment_partial_update_query_as_sub_resource import Se
 from openapi_client.model.send_options import SendOptions
 from openapi_client.model.send_options_sub_object import SendOptionsSubObject
 from openapi_client.model.send_strategy_sub_object import SendStrategySubObject
-from openapi_client.model.send_strategy_sub_object_options import SendStrategySubObjectOptions
 from openapi_client.model.send_time_sub_object import SendTimeSubObject
 from openapi_client.model.static_schedule_options import StaticScheduleOptions
 from openapi_client.model.subscription import Subscription
@@ -181,14 +181,20 @@ from openapi_client.model.tag_group_create_query_as_sub_resource_attributes impo
 from openapi_client.model.tag_group_update_query import TagGroupUpdateQuery
 from openapi_client.model.tag_group_update_query_as_sub_resource import TagGroupUpdateQueryAsSubResource
 from openapi_client.model.tag_group_update_query_as_sub_resource_attributes import TagGroupUpdateQueryAsSubResourceAttributes
+from openapi_client.model.tag_segment_op import TagSegmentOp
+from openapi_client.model.tag_segment_op_data_inner import TagSegmentOpDataInner
 from openapi_client.model.tag_update_query import TagUpdateQuery
 from openapi_client.model.tag_update_query_as_sub_resource import TagUpdateQueryAsSubResource
+from openapi_client.model.tag_update_query_as_sub_resource_attributes import TagUpdateQueryAsSubResourceAttributes
 from openapi_client.model.template_clone_query import TemplateCloneQuery
 from openapi_client.model.template_clone_query_as_sub_resource import TemplateCloneQueryAsSubResource
 from openapi_client.model.template_clone_query_as_sub_resource_attributes import TemplateCloneQueryAsSubResourceAttributes
 from openapi_client.model.template_create_query import TemplateCreateQuery
 from openapi_client.model.template_create_query_as_sub_resource import TemplateCreateQueryAsSubResource
 from openapi_client.model.template_create_query_as_sub_resource_attributes import TemplateCreateQueryAsSubResourceAttributes
+from openapi_client.model.template_render_query import TemplateRenderQuery
+from openapi_client.model.template_render_query_as_sub_resource import TemplateRenderQueryAsSubResource
+from openapi_client.model.template_render_query_as_sub_resource_attributes import TemplateRenderQueryAsSubResourceAttributes
 from openapi_client.model.template_update_query import TemplateUpdateQuery
 from openapi_client.model.template_update_query_as_sub_resource import TemplateUpdateQueryAsSubResource
 from openapi_client.model.template_update_query_as_sub_resource_attributes import TemplateUpdateQueryAsSubResourceAttributes
@@ -200,7 +206,6 @@ from openapi_client.model.unsubscription_create_job_create_query_as_sub_resource
 from openapi_client.model.unsubscription_create_job_create_query_as_sub_resource_attributes import UnsubscriptionCreateJobCreateQueryAsSubResourceAttributes
 from openapi_client.model.unsuppression_create_job_create_query import UnsuppressionCreateJobCreateQuery
 from openapi_client.model.unsuppression_create_job_create_query_as_sub_resource import UnsuppressionCreateJobCreateQueryAsSubResource
+from openapi_client.model.unsuppression_create_job_create_query_as_sub_resource_attributes import UnsuppressionCreateJobCreateQueryAsSubResourceAttributes
 from openapi_client.model.utm_param_info import UtmParamInfo
-from openapi_client.model.v2_template_render_query import V2TemplateRenderQuery
 from openapi_client.model.v2_template_render_query_as_sub_resource import V2TemplateRenderQueryAsSubResource
-from openapi_client.model.v2_template_render_query_as_sub_resource_attributes import V2TemplateRenderQueryAsSubResourceAttributes
